from inc_noesis import *

BITRATE_ENUM_MAP = {
    2: (4, "R8G8B8A8"),
    20: (3, "R8G8B8"),
    51: (2, "A16"),
    40: (1, "A8")
}

def registerNoesisTypes():
    handle = noesis.register("RTEX images", ".rtex")
    noesis.setHandlerTypeCheck(handle, RTEXCheckType)
    noesis.setHandlerLoadRGBA(handle, RTEXLoadRGBA)
    # noesis.logPopup()
    return 1

#check if it's this type based on the data
def RTEXCheckType(data):
    bs = NoeBitStream(data)
    Header = bs.readBytes(4).decode("ASCII")
    if Header != 'RTEX':
        return 0
    return 1
    
def RTEXLoadRGBA(data, texList):
    rapi.processCommands("-texnorepfn")
    bs = NoeBitStream(data)
    bs.seek(8)
    dimensions = bs.readUInt()
    dimensions2 = bs.readUInt()
    imgWidth = dimensions & 0xFFFF
    imgHeight = dimensions >> 16
    imgWidth2 = dimensions2 & 0xFFFF
    imgHeight2 = dimensions2 >> 16
    if imgWidth != imgWidth2:
        imgWidth = imgWidth2
    imgDataZOff = bs.readInt() + 0x06
    imgDataZSize = bs.readInt() - 0x06
    bitrateEnumValue = bs.readByte()
    if bitrateEnumValue in BITRATE_ENUM_MAP:
        bytesPerPixel, bitrateString = BITRATE_ENUM_MAP.get(bitrateEnumValue)
    else:
        print("\nUnknown enum value at 0x18: "+str(bitrateEnumValue)+". Tell the plugin dev!\n")
        # Default to processing as 32bpp
        bytesPerPixel, bitrateString = (4, "R8G8B8A8")
    
    Name = rapi.getInputName()
    outName = rapi.getExtensionlessName(Name)
    
    bs.seek(imgDataZOff)
    compImgData = bs.readBytes(imgDataZSize)
    imgDataSize = (imgWidth*imgHeight)*bytesPerPixel
    decompImgData = rapi.decompInflate(compImgData, imgDataSize)
    imgDisp = rapi.imageDecodeRaw(decompImgData, imgWidth, imgHeight, bitrateString)
    texList.append(NoeTexture(outName, imgWidth, imgHeight, imgDisp, noesis.NOESISTEX_RGBA32))
    return 1
